@@ -201,6 +201,7 @@ class ReferenceCertifier(Certifier):
                 "Checking reference modes for", repr(self.filename)):
             if self.mode_columns:
                 self.certify_reference_modes()
+
         with self.error_on_exception(
                 "Dumping provenance for", repr(self.filename)):
             if self._dump_provenance_flag:
@@ -467,7 +468,11 @@ class ReferenceCertifier(Certifier):
                 different += 1
             old_value = handle_nan(old_value)
             new_value = handle_nan(new_value)
-            if np.any(old_value != new_value):
+            try:
+                if np.any(old_value != new_value):
+                    different += 1
+            except ValueError:
+                log.warning(f"Cannot compare arrays in column {old_key} for mode {mode}")
                 different += 1
         return different
 
@@ -481,7 +486,7 @@ class ReferenceCertifier(Certifier):
         if asdf_standard_version:
             pmap = crds.get_pickled_mapping(self.context, ignore_checksum="warn")
             asdf_standard_requirement = pmap.get_asdf_standard_requirement()
-            if not asdf_standard_version in asdf_standard_requirement:
+            if not asdf_standard_version in asdf_standard_requirement.specifier:
                 log.error(
                     "ASDF Standard version",
                     asdf_standard_version,
@@ -543,7 +548,12 @@ def table_mode_dictionary(generic_name, tab, mode_keys):
 
 def handle_nan(var):
     """Map nan values to 'nan' so that 'nan' == 'nan'."""
-    if isinstance(var, (np.float32, np.float64, np.float128)) and np.isnan(var):
+    try:
+        from numpy import float128
+        floats = (np.float32, np.float64, np.float128)
+    except ImportError:
+        floats = (np.float32, np.float64)
+    if isinstance(var, floats) and np.isnan(var):
         return 'nan'
     elif isinstance(var, np.ndarray) and var.shape == () and np.any(np.isnan(var)):
         return 'nan'
@@ -677,7 +687,7 @@ class UnknownCertifier(Certifier):
 class AsdfCertifier(ReferenceCertifier):
     """Certifier for ADSF type,  invoke data models checks."""
 
-    _VERSION_RE = re.compile(f"^[0-9]+\.[0-9]+\.[0-9]+$")
+    _VERSION_RE = re.compile(r"^[0-9]+\.[0-9]+\.[0-9]+$")
 
     def certify(self):
         """Certify an unknown format file."""
@@ -947,7 +957,7 @@ def check_rmap_updates(observatory, context, filepaths):
         old_rmap = pmap.get_imap(instrument).get_rmap(filekind)
         new_rmap = "/tmp/" + old_rmap.basename
         log.info("Checking rmap update for", (instrument, filekind), "inserting files", references2)
-        refactor.rmap_insert_references(old_rmap.filename, new_rmap, references2)
+        refactor.rmap_insert_references(old_rmap.filename, new_rmap, references2, observatory=observatory)
 
         banner()
         certify_file(new_rmap, context)    # check for partial overlaps
@@ -1025,7 +1035,7 @@ For more information on the checks being performed,  use --verbose or --verbosit
         self.add_argument("-s", "--sync-files", dest="sync_files", action="store_true",
                           help="Fetch any missing files needed for the requested difference from the CRDS server.")
         self.add_argument("-l", "--allow-schema-violations", action="store_true",
-                          help="Report jwst.datamodels schema violations as warnings rather than as errors.")
+                          help="Report datamodels schema violations as warnings rather than as errors.")
         self.add_argument("-f", "--run-fitsverify", action="store_true",
                           help="Run fitsverify for additional external checks on FITS files. cfitsio library must be installed separately.")
         self.add_argument("-u", "--check-rmap-updates", action="store_true",
