@@ -517,9 +517,9 @@ class PedigreeValidator(PedigreeBaseValidator):
 class JwstpedigreeValidator(PedigreeBaseValidator):
     """Validates &JWSTPEDIGREE fields."""
 
-    _values = ["INFLIGHT", "GROUND", "DUMMY", "SIMULATION"]
-    _values_wo_date = ["GROUND", "DUMMY", "SIMULATION"]
-    _values_w_date = ["INFLIGHT"]
+    _values = ["INFLIGHT", "GROUND", "MODEL", "DUMMY", "SIMULATION"]
+    _values_wo_date = ["GROUND", "MODEL", "DUMMY", "SIMULATION"]
+    _values_w_date = ["INFLIGHT", "MODEL"]
     _dated_format = "INFLIGHT YYYY-MM-DD YYYY-MM-DD"
 
     def validate_date(self, date):
@@ -687,7 +687,7 @@ class KernelunityValidator(Validator):
         # super(KernelunityValidator, self).check_header(filename, header)
         array_name = self.complex_name
         all_data = header[array_name].DATA.transpose()
-        images = int(np.product(all_data.shape[:-2]))
+        images = int(np.prod(all_data.shape[:-2]))
         images_shape = (images,) + all_data.shape[-2:]
         images_data = np.reshape(all_data, images_shape)
         log.verbose("File=" + repr(os.path.basename(filename)),
