@@ -104,15 +104,21 @@ def set_crds_server(url):
     S = CheckingProxy(URL, version="1.0")
 
 
-def get_crds_server():
+def get_crds_server(obs=None):
     """Return the base URL for the CRDS JSON RPC server.
     """
-    url = URL[:-len(URL_SUFFIX)]
-    if not url.startswith("https://") and "localhost" not in url:
-        log.warning("CRDS_SERVER_URL does not start with https://  ::", url)
+    try:
+        url = URL[:-len(URL_SUFFIX)]
+        if not url.startswith("https://") and "localhost" not in url:
+            log.warning("CRDS_SERVER_URL does not start with https://  ::", url)
+    except NameError:
+        if obs is None:
+            obs = "jwst"
+        url = os.environ.get("CRDS_SERVER_URL", f"https://{obs}-serverless.stsci.edu")
     return url
 
 
+
 # =============================================================================
 
 
@@ -480,7 +486,13 @@ def _get_server_info():
     """
     config_uri = config.get_uri("server_config")
     try:
-        if config_uri != "none":
+        if config_uri.startswith("s3://"):
+            log.verbose(f"Loading config from URI '{config_uri}'.")
+            content = utils.get_uri_content(config_uri)
+            info = ast.literal_eval(content)
+            info["status"] = "s3"
+            info["connected"] = True
+        elif config_uri != "none":
             log.verbose(f"Loading config from URI '{config_uri}'.")
             content = utils.get_uri_content(config_uri)
             info = ast.literal_eval(content)
@@ -659,9 +671,7 @@ def get_default_observatory():
     obs = config.OBSERVATORY.get()
     if obs not in ["none", "", None]:
         return obs
-    return observatory_from_string(get_crds_server()) or \
-        get_server_observatory() or \
-        "jwst"
+    return observatory_from_string(get_crds_server()) or "jwst"
 
 
 def observatory_from_string(string):
