@@ -625,7 +625,7 @@ def check_crds_ref_subdir_mode(mode):
 CRDS_MODE = StrConfigItem("CRDS_MODE", default="auto",
     comment="""Selects where bestrefs are performed, locally, remotely (on the CRDS server),
     or automatically chosen by comparing client version to server version.""",
-    valid_values=["local", "remote", "auto"])
+    valid_values=["local", "remote", "auto", "s3"])
 
 def get_crds_processing_mode():
     """Return the preferred location for computing best references when
@@ -1573,6 +1573,8 @@ OBSERVATORY = StrConfigItem("CRDS_OBSERVATORY", None,
     lower=True
 )
 
+S3_BUCKET = StrConfigItem("CRDS_S3_BUCKET", None, "S3 bucket from which to download CRDS references and mappings.", lower=True)
+
 # -------------------------------------------------------------------------------------
 def get_uri(filename):
     """Return an appropriate s3:// or https:// URI for the specified filename based
