@@ -60,7 +60,7 @@ import pickle
 from . import rmap, log, utils, config
 from .constants import ALL_OBSERVATORIES
 from .log import srepr
-from .exceptions import CrdsError, CrdsBadRulesError, CrdsBadReferenceError, CrdsConfigError, CrdsDownloadError
+from .exceptions import CrdsError, CrdsBadRulesError, CrdsBadReferenceError, CrdsConfigError, CrdsDownloadError, CrdsNetworkError, ServiceError
 from crds.client import api
 
 # import crds  # forward
@@ -447,7 +447,10 @@ def get_final_context(info, context):
     else:
         # Default for JWST if no env context and no explicit context is BUILD CONTEXT for installed jwst version
         if info.observatory == 'jwst':
-            input_context = api.get_build_context('jwst')
+            try:
+                input_context = api.get_build_context('jwst')
+            except (ServiceError, AttributeError):
+                input_context = latest_context
         # For other missions, default is latest (formerly operational) context
         else:
             input_context = latest_context
@@ -515,7 +518,7 @@ class ConfigInfo(utils.Struct):
 
         returns 'local' or 'remote'
         """
-        mode = config.get_crds_processing_mode()  # local, remote, auto
+        mode = config.get_crds_processing_mode()  # local, remote, auto, s3
         if mode == "auto":
             eff_mode = "remote" if (self.connected and hasattr(self, "force_remote_mode") and self.force_remote_mode) else "local"
         else:
@@ -528,7 +531,7 @@ class ConfigInfo(utils.Struct):
 
 @utils.cached
 def get_config_info(observatory):
-    """Get the operational context and server s/w version from (in order of priority):
+    """Get the latest context and server s/w version from (in order of priority):
 
     1. The server.
     2. The cache from a prior server access.
@@ -544,8 +547,8 @@ def get_config_info(observatory):
                 info.status = "cache"
                 info.connected = True
                 log.verbose("Using CACHED CRDS reference assignment rules last updated on", repr(info.last_synced))
-    except CrdsError as exc:
-        if "serverless" not in api.get_crds_server():
+    except (CrdsError,NameError,CrdsNetworkError) as exc:
+        if "serverless" not in api.get_crds_server(obs=observatory):
             log.verbose_warning("Couldn't contact CRDS server:", srepr(api.get_crds_server()), ":", str(exc))
         info = load_server_info(observatory)
         info.status = "cache"
@@ -569,7 +572,7 @@ def update_config_info(observatory):
     if config.writable_cache_or_verbose("skipping config update."):
         info = get_config_info(observatory)
         if info.connected and info.effective_mode == "local":
-            log.verbose("Connected to server and computing locally, updating CRDS cache config and operational context.")
+            log.verbose("Connected to server and computing locally, updating CRDS cache config and latest context.")
             cache_server_info(info, observatory)  # save locally
         else:
             log.verbose("Not connected to CRDS server or operating in 'remote' mode,  skipping cache config update.", verbosity=65)
